#
# spec file for package libgpod
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libsoname  %{name}4
%define _udevdir %(pkg-config --variable udevdir udev)
%if 0%{?suse_version} > 1500
%define libplist2 1
%else
%define libplist2 0
%endif
Name:           libgpod
Version:        0.8.3
Release:        14.3
Summary:        Library to Manipulate Songs and Playlists Stored on an iPod
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.gtkpod.org/libgpod.html
Source:         http://downloads.sourceforge.net/project/gtkpod/libgpod/libgpod-0.8/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
Patch0:         libgpod-swig-3.0.patch
Patch1:         0001-Fix-spelling-errors-in-comments-and-strings-using-co.patch
Patch2:         0002-323-Segmentation-fault-when-opening-ipod.patch
Patch3:         0003-Fixed-PList-deprication.patch
Patch4:         libgpod-Use-libplist-2.0.patch
Patch5:         0004-gcc14.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libimobiledevice-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  sg3_utils-devel
BuildRequires:  sqlite3-devel
BuildRequires:  swig
BuildRequires:  taglib-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(udev)
%if %{libplist2}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig(libplist-2.0)
%else
BuildRequires:  pkgconfig(libplist)
%endif

%description
libgpod is a library meant to abstract access to iPod content. It
provides an API to retrieve the list of files and
playlists stored on an iPod, modify them, and save them back to the iPod.

%package -n %{libsoname}
Summary:        Library to Manipulate Songs and Playlists Stored on an iPod
# Add provides for installability of lang package
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n %{libsoname}
libgpod is a library meant to abstract access to iPod content. It
provides an API to retrieve the list of files and
playlists stored on an iPod, modify them, and save them back to the iPod.

%package devel
Summary:        Development files for libgpod
Group:          Development/Libraries/C and C++
Requires:       %{libsoname} = %{version}
Requires:       glib2-devel
Requires:       glibc-devel

%description devel
libgpod is a library meant to abstract access to iPod content. It
provides an API to retrieve the list of files and
playlists stored on an iPod, modify them, and save them back to the iPod.

This package provides the development files to use libgpod.

%package doc
Summary:        Documentation for libgpod
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
libgpod is a library meant to abstract access to iPod content. It
provides an API to retrieve the list of files and
playlists stored on an iPod, modify them, and save them back to the iPod.

This package provides development documentation for libgpod.

%package tools
Summary:        Tools for libgpod
Group:          Productivity/Multimedia/Other
Supplements:    (%{libsoname} and udev)

%description tools
libgpod is a library meant to abstract access to iPod content. It
provides an API to retrieve the list of files and
playlists stored on an iPod, modify them, and save them back to the iPod.

This package includes support tools for libgpod.

%lang_package

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%if %{libplist2}
%patch -P 4 -p1
%endif
%patch -P 5 -p1

%build
%if %{libplist2}
autoreconf -fvi
%endif
%configure --disable-silent-rules \
           --disable-static \
           --with-udev-dir=%{_udevdir} \
           --with-python=no \
           --without-hal
%make_build

%install
%make_install
%find_lang libgpod
rm bindings/python/examples/Makefile*
find %{buildroot} -type f -name "*.la" -delete -print
rm %{buildroot}%{_libdir}/pkgconfig/libgpod-sharp.pc
%fdupes -s %{buildroot}

%post   -n %{libsoname} -p /sbin/ldconfig
%postun -n %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%license COPYING
%doc AUTHORS ChangeLog NEWS README README.SysInfo
%{_libdir}/libgpod.so.4*

%files tools
%{_bindir}/ipod-read-sysinfo-extended
%{_udevdir}/ipod-set-info
%{_udevdir}/iphone-set-info
%{_udevdir}/rules.d/90-libgpod.rules

%files devel
%{_includedir}/gpod-1.0/
%{_libdir}/libgpod.so
%{_libdir}/pkgconfig/libgpod-1.0.pc

%files doc
%doc %{_datadir}/gtk-doc/html/libgpod/

%files lang -f libgpod.lang

%changelog
* Thu Jul  4 2024 pgajdos@suse.com
- fix build with gcc14
- added patches
  + 0004-gcc14.patch
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Sep  5 2022 Matej Cepl <mcepl@suse.com>
- Don't hide behind bcond_with stuff, just clean the SPEC (if you
  want to recover we have versioning system for that).
* Wed Jan 20 2021 Michal Suchanek <msuchanek@suse.com>
- Use libplist-2.0 on Tumbleweed:
  libgpod-Use-libplist-2.0.patch
* Tue Feb  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Tue Jan 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Disable python2 module: switch bcond_without python2 to _with
  python2.
* Mon Jun 11 2018 bjorn.lie@gmail.com
- Change bcond_without mono to bcond_with mono, no longer build
  mono support/sub-package by default.
* Tue Jan 23 2018 jengelh@inai.de
- Fix groups of SRPM and documentation. Make doc noarch.
  Trim bias from description.
* Tue Jan 23 2018 tchvatal@suse.com
- Conditionalize python2 module build as it is not compatible with
  python3 at all and we do not need it by default
  * This allows to build in python3 only enviroment
- Run over a bit with spec-cleaner
* Fri Oct 23 2015 tuukka.pasanen@ilmi.fi
- Added patch that prevents segfault when using newer iPod and iPhone (< iOS 5)
  0002-323-Segmentation-fault-when-opening-ipod.patch
- Added patch that corrects few strings
  0001-Fix-spelling-errors-in-comments-and-strings-using-co.patch
- Added patch that corrects compiling with newer libplist
  0003-Fixed-PList-deprication.patch
* Sun Jun 21 2015 crrodriguez@opensuse.org
- Use libusb-1_0-devel as BuildRequires not libusb-devel
  as the old libusb compatibility layer is not used.
* Tue Mar 24 2015 dvlaeev@suse.com
- Change bcond back again.. It turned out to be that mono bindings
  are wanted by the openSUSE community.
* Fri Mar 20 2015 dvlaeev@suse.com
- Build without Mono by default
* Mon Jan 26 2015 dimstar@opensuse.org
- Add libgpod-swig-3.0.patch: Fix build with SWIG 3.0.
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 0.8.3:
  + Add support for libimobiledevice 1.1.5.
  + Remove use of some deprecated glib functions.
  + Fix various issues found using clang/cppcheck.
  + Improve robustness of the iphone callout.
- Drop libgpod-libimobiledevice-fix.patch, fixed upstream.
- Stop passing --enable-udev to configure, now default enabled.
- Remove conditional BuildRequires for obsolete openSUSE versions
  (11.2 and older, no longer supported as evergreen either).
- Stop passing --with-hal-callouts-dir=%%{_libexecdir}/hal and
  and --disable-udev only needed for obsolete openSUSE versions.
* Mon Jul 15 2013 coolo@suse.com
- fix build in factory by porting to new libimobiledevice api
* Fri Mar 22 2013 schwab@suse.de
- Move %%{_libdir}/libgpod to sharp subpackage
* Tue Mar 19 2013 dmueller@suse.com
- make mono dependency optional (still enabled by default)
* Tue Nov 27 2012 alinm.elena@gmail.com
- install the udev rules in /usr/lib/udev for factory and above
* Thu Aug  4 2011 chris@computersalat.de
- spec mods
  * add libsoname macro
  * one License info is enough ;)
- fix deps
  o doc pkg does not really need libgpod4
* Wed Jul 27 2011 vuntz@opensuse.org
- Add baselibs.conf as source in .spec.
* Sun Jul 24 2011 vuntz@opensuse.org
- Update to version 0.8.2:
  + Fix mono binding on 32 bit systems
  + Better iOS 4.3 support
  + Dynamic loader for libhashab.so, which can be used for
    iPhone 4/iPod Touch 4/iPad/Nano 6g support
  + Make smartplaylists case-insensitive to match what iTunes does
  + More robust Shuffle support in udev helper
  + Various compilation fixes and build system improvements
  + Bug fixes
  + Updated translations.
- Drop fix-mono-alignment.patch: fixed upstream.
- Move ownership of %%{_libdir}/libgpod from libgpod-sharp to
  libgpod4, as it'll make it easier for people to manually copy
  libhashab.so there.
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
* Mon Apr  4 2011 gburt@suse.de
- Fix Mono alignment issue causing broken C# bindings
  + Add fix-mono-alignment.patch
* Mon Mar 28 2011 gburt@suse.de
- fix libgpod-sharp to depend on libgpod4 (bnc#683171)
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- disable silent rules, break post build checks
- fix -devel package dependencies
* Wed Oct 13 2010 vuntz@opensuse.org
- Update to version 0.8.0:
  + Shuffle 3g/4g bug fixes
  + Bug fixes related to the addition of the new ipod models
  + Silence some useless runtime warnings
* Fri Oct  8 2010 vuntz@opensuse.org
- Make libgpod4 provide libgpod to make libgpod-lang installable.
- Change libgpod Requires to libgpod4 in libgpod-doc.
- Change supplements of libgpod-tools to reference libgpod4 too.
* Thu Sep 30 2010 gburt@suse.de
- Don't require libimobiledevice on older distros
* Thu Sep 30 2010 vuntz@opensuse.org
- Update to version 0.7.95:
  + Improvements to the generation of the sqlite databases (used by
    iOS devices), in particular improved playcounts handling.
  + Bug fixes and playlist support for mono bindings
  + Small itdb_start_sync/itdb_stop_sync behaviour change, now the
    calls need to be paired, but itdb_start_sync can be called N
    times, and the "Sync in Progress" screen will only go away
    after the Nth call to itdb_stop_sync
  + Be more smart when auto-guessing whether to use iPod_Control or
    iTunes_Control
  + Improve error handling in itdb_init and itdb_write, before that
    there were error cases that were not properly reported to the
    caller
* Sat Sep 11 2010 vuntz@opensuse.org
- Add mono-devel and gtk-sharp2 BuildRequires to build .NET
  bindings.
- Create libgpod-sharp subpackage.
- Improve summaries and descriptions.
- Remove explicit glib2-devel and gtk2-devel Requires of devel
  package: they will automatically get added with the
  pkgconfig()-style Requires.
- Remove check for obsolete version of openSUSE (10.3).
* Tue Sep  7 2010 coolo@novell.com
- fix requires of -devel package
* Wed Sep  1 2010 vuntz@opensuse.org
- Update to version 0.7.94:
  + Shuffle 3g and 4g support
  + CLI bindings
  + artwork fixes
  + various bug fixes
* Wed Sep  1 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Thu May 27 2010 vuntz@opensuse.org
- Add libimobiledevice-devel BuildRequires for iPod touch / iPhone
  support. This is fate#308282.
* Thu Apr  8 2010 davejplater@gmail.com
- Update to version 0.7.93 changed 80-libgpod.rules to 90-libgpod.rules
  + various bug fixes in HAL/udev iPhone callout which would make it
    fail to dump SysInfoExtended more often than not.
  + fix iPod Classic 80GB support (Joeny Ang).
  + handle TV Shows, Movies and Music Videos on iPhone better
    (Joel Smith)
  + fix python bindings for the iPhone (Adrian Sampson).
  + fix OnTheGo playlist parsing (the 1st on-the-go playlist was
    always ignored).
  + automatically call itdb_shuffle_write when itdb_write is
    called if needed.
  + some gint32/guint32 changes were made in the public API,
  + lower udev rule priority so that it runs after the usbmux
    udev rule.
* Sat Mar 27 2010 vuntz@opensuse.org
- Update to version 0.7.92:
  + make the temporary mountpoint used by the HAL/udev callouts
    configurable at compile time. This is helpful for distros who
    use SELinux to restrict what the callouts can do.
  + tag .mov files as video files
  + add itdb_start_sync and itdb_stop_sync functions to show/hide
    the "Sync in progress" screen on iPhones and iPod Touch (this
    is a no-op on other devices)
  + set udisks-compliant names for icons in the udev callout
    instead of using the old devicekit-disks names
  + prefix libgpod udev rule with a number (80-) since it's the
    usual way of naming rules
- Changes from version 0.7.91:
  + add udev callout, to replace the HAL one
  + fix playback order when sorting by composer
  + fix handling of nano5g with the latest firmware
  + various bug fixes
- Changes from version 0.7.90:
  + iPhoneOS 3.x support (iPhone and iPod Touch), thanks to the
    libimobiledevice stack
  + iPod Nano 5G support
  + iPod Classic 3G support
  + fix iPod Nano 4G 4GB serial number (bgo#599772)
  + properly read timezone information from iPod Classic and Nano 4G
  + artwork writing bug fixes
  + iTunesDB reading bug fixes
  + add code sample showing how to copy a file to the iPod
  + export podsleuth-like information to HAL
- Remove perl-XML-Parser, python-eyeD3 BuildRequires.
- Add glib2-devel, libplist-devel, libusb-devel, sqlite3-devel
  BuildRequires.
- Only build hal support on 11.2 and earlier, and use udev support
  instead on 11.3 and later.
- Rename libgpod-python to python-gpod, and add appropriate
  Provides/Obsoletes.
- Add py_requires to python-gpod.
- Clean up packaging.
* Mon Jul 27 2009 coolo@novell.com
- do not exclude files not in other subpackages
* Sat Jul 25 2009 tittiatcoke@gmail.com
- Update to version 0.7.2
  * fix crash when generating the album list when a track has a NULL album
  * prevent iTunes from thinking that the database on the iPhone is corrupt
  * fix nano3g/ipod classic artwork information
  * test if an iPod supports podcasts or not
  * test if an iPod support chapter images or not
  * add ipod time sync support using information from the rockbox project.
    It's still preliminary
  * Update translations
  * bug fixes and code cleanup all over the place
* Thu Jul 23 2009 tittiatcoke@gmail.com
- Using variable for %%{_libexecdir} to ensure the LSB standards
* Sun Jul 12 2009 tittiatcoke@gmail.com
- Changed the configure option to ensure that all files are placed
  in the correct directories conform lsb standards
* Wed Jun  3 2009 mszeredi@suse.cz
- Add gtk2-devel as a requirement for libgpod-devel.  This is needed
  to satisfy a pkg-config dependency on gdk-pixbuf-2.0
* Mon May 25 2009 coolo@suse.de
- use %%name-lang - otherwise the shared library policy is not
  working
* Fri Jan 30 2009 wstephenson@suse.de
- Rename library package to libgpod4
- Update to version 0.7.0
  * support for iPod Nano 4th generation
  * support for "sparse artwork" writing
  * jump table support
  * chapter data support
  * improved timezone handling
  * translation updates
  * much more complete API doc
  * simplification of the cover art handling API
  * extensive plist parser
  * add mapping from iPod serial numbers to iPod models
  * portability improvements to windows and macosx
  * reworked handling of artwork formats
  * python bindings are more consistent with other python container objects
  * bug fixes and code cleanup all over the place
* Wed Dec 17 2008 dmueller@suse.de
- fix build for 10.3
* Tue Dec 16 2008 coolo@suse.de
- require lang subpackage
* Tue Sep  9 2008 hvogel@suse.de
- backport scsi fixes (just some missing headers) and downgrade
  to official release again to not break gtkpod
* Mon Sep  1 2008 crrodriguez@suse.de
- fix build by updating to an slightly newer snap 0.6.1+20080901.
* Mon May 26 2008 ro@suse.de
- buildreq sg3_utils-devel instead of scsi
* Thu Feb 14 2008 dmueller@suse.de
- libgpod3 is not a renamed package so remove the provides/obsoletes
* Sat Feb  9 2008 crrodriguez@suse.de
- fix some more packaging errors.
- Remove uneeded dependencies in the -devel package, it only needs
  glib2-devel and glibc-devel (dependant packages may need changes)
- remove "la" files.
* Tue Jan 29 2008 hvogel@suse.de
- fix some specfile errors
- move nano support tools to tools subpackage which supplements
  the main package.
* Wed Jan 23 2008 dmueller@suse.de
- fix iPod nano support
* Wed Jan 16 2008 hvogel@suse.de
- Update to version 0.60
- Rename library package to libgpod3
* Wed Jul  4 2007 hvogel@suse.de
- Update to version 0.5.2
  * namespace cleanup
  * updated translations
  * various fixes
  * New API functions to facilitate copying to the iPod in a
    background thread and implementation of own copying code
  * better sort order on the iPod when displaying
- renamed main package according to Shared Library Packaging Policy
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Feb  1 2007 hvogel@suse.de
- Update to 0.42
- build python bindings
* Tue Dec 19 2006 sbrabec@suse.cz
- Spec file cleanup.
- Splitted libgpod-doc from libgpod-devel.
* Mon Oct 23 2006 hvogel@suse.de
- Update to version 0.4.0
  * added definitions for new sixth generation
    iPod Videos, iPod Nanos and iPod Shuffle
* Sat Jul  1 2006 cthiel@suse.de
- update to version 0.3.2
  * db-artwork-writer.c: increased IPOD_MMAP_SIZE from 2 to 16 MB as
    a temporary workaround until a propoer solution can be
    implemented.
  * db-itunes-parser.h: replaced the #pragma pack(4) with an
    'packed' attribute on _MhiiHeader only.
  * ipod-device.c: (ipod_device_set_property): fixed possible
    segfault when hald is present.
  * configure.ac, po/es.po: added Spanish translation catalog
  * libgpod-1.0.pc: added gobject-2.0 to 'Requires:' list
  * src/db-itunes-parser.h: add '#pragma pack(4)' to fix 64bit issue
    with padding (at least as a temporary fix).
  * src/ipod-device.c: added HP type color photo ipod 'S492'.
  * po/ja.po: updated Japanese catalog
  * src/ipod-device.c: (ipod_device_set_property): fixed bug that
    caused ipod-detection to fail if hal daemon was not running. As
    a consequence cover art was not written to the iPod.
  * src/itdb_itunesdb.c: (itunesstats_read) Fixed error when reading
    the Shuffle's stat file (0x18 was used as minimal record length
    instead of decimal '18').
  * src/itdb_itunesdb.c, src/itdb_playlist.c, src/ithumb-writer.c:
    removed nested-functions.
  * src/ipod-device.c: (ipod_device_set_property) check hal_context
    before accessing it to avoid segfault when hald is not running.
    (ipod_device_hal_initialize) fixed memory leak: 'error' was not
    freed if libhal_ctx_init() failed.
    (ipod_device_get_model_index_from_table): fix warning about
    unused computed value (thanks to Martin Aumueller)
  * src/ipod-device.c: don't ignore return value of
    fread/fwrite/ftell because of possible compiler warnings.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 hvogel@suse.de
- Update to version 0.3.0
* Wed Nov 30 2005 sbrabec@suse.cz
- New SuSE package, version 0.2.0.
